## convertdata
# This python script converts the csv file obtained from the NIST:XCOM database into a ROOT script, which creates ROOT TGraphs with the required relative cross sections for the photon simulation
#
# This file is part of the photonSim package
# Copyright 2020, Philipp Kampmann 
#                                  
# Licensed under GPL-3.0-or-later
#
import csv
import sys
import os

inputFileName = sys.argv[1]
inputFile =  open(inputFileName,'r')
myReader=csv.reader(inputFile,delimiter=' ')
next(myReader) #skip the first three rows as they are header
next(myReader)
next(myReader)
fileTitle = os.path.splitext(inputFileName)[0]
myOutputFile=open(fileTitle+'.C','w')

myOutputFile.write('void '+fileTitle+'(){\n')
myOutputFile.write('\n\n')
myOutputFile.write('\tTGraph* comptonGraph = new TGraph();\n')
myOutputFile.write('\tcomptonGraph->SetName("Compton");\n')
myOutputFile.write('\tUInt_t compCnt = 0;\n')
myOutputFile.write('\tTGraph* rayleighGraph = new TGraph();\n')
myOutputFile.write('\trayleighGraph->SetName("RaylScat");\n')
myOutputFile.write('\tUInt_t raylCnt = 0;\n')
myOutputFile.write('\tTGraph* photoGraph = new TGraph();\n')
myOutputFile.write('\tphotoGraph->SetName("PhotoEff");\n')
myOutputFile.write('\tUInt_t photCnt = 0;\n')
myOutputFile.write('\n\n')

for row in myReader:
    compString = '\tcomptonGraph->SetPoint(compCnt++,{0},{1});\n'.format(float(row[0]),float(row[2])/float(row[4]))
    raylString = '\trayleighGraph->SetPoint(raylCnt++,{0},{1});\n'.format(float(row[0]),float(row[1])/float(row[4]))
    photString = '\tphotoGraph->SetPoint(photCnt++,{0},{1});\n'.format(float(row[0]),float(row[3])/float(row[4]))
    myOutputFile.write(compString)
    myOutputFile.write(raylString)
    myOutputFile.write(photString)


myOutputFile.write('\n\n')
myOutputFile.write('TFile* outputFile = new TFile("{0}.root","RECREATE");\n'.format(fileTitle))
myOutputFile.write('comptonGraph->Write();\n'.format(fileTitle))
myOutputFile.write('rayleighGraph->Write();\n'.format(fileTitle))
myOutputFile.write('photoGraph->Write();\n'.format(fileTitle))
myOutputFile.write('outputFile->Write();\n'.format(fileTitle))
myOutputFile.write('outputFile->Close();\n'.format(fileTitle))

myOutputFile.write('\n\n')
myOutputFile.write('}')

