/*************************************************************************
 * exampleMain.C                                                         *
 * Example usage of the class photonSim                                  *
 *                                                                       *
 * This file is part of the photonSim package                            *
 * Copyright 2020, Philipp Kampmann                                      *
 *                                                                       *
 * Licensed under GPL-3.0-or-later                                       *
 *                                                                       *
 *************************************************************************/


#include<iostream>
#include"photonSim.hh"


int main(){

  //initialize - the simulation will read in the cross sections from the input root file during construction 
  photonSim* mySim =  new photonSim();

  //as the simulation returns on reference one needs to declare the corresponding variables
  double eGamma;        // energy of the gamma
  double eElectron;     // kinetic energy of the electron
  
  //Simulate one process with gamma energy = 0.5 MeV
  eGamma = 0.5; //MeV
  std::cout << "Before first scattering: E_gamma = " << eGamma <<"\tE_Electron = " <<eElectron<< '\n'; //eElectron is not initialized here 
  mySim->simulatePhoton(eGamma,eElectron); 
  std::cout << "After first scattering: E_gamma = " << eGamma <<"\tE_Electron = " <<eElectron<< '\n';
  
  //As it returns on reference, it is straightforward to let the gamma interact further:
  //If the gamma is absorbed, its energy is set to 0.
  while(eGamma>0){
    mySim->simulatePhoton(eGamma,eElectron); 
    std::cout << "Next iteration: E_gamma = " << eGamma <<"\tE_Electron = " <<eElectron<< '\n';
  }


  // clean up
  delete mySim; 

  return 0;
};


