/*************************************************************************
 * photonSim.hh                                                          *
 * Header file for the class photonSim                                   *
 *                                                                       *
 * This file is part of the photonSim package                            *
 * Copyright 2020, Philipp Kampmann                                      *
 *                                                                       *
 * Licensed under GPL-3.0-or-later                                       *
 *                                                                       *
 *************************************************************************/

#pragma once

#include<TF1.h>
#include<TGraph.h>

class photonSim{

  private:
    /// This function is used as interface between the required form by ROOT and the implemented klein-nishina cross section - p[0] is a normalization, p[1] is the photon energy
    double pdf_theta(double* x, double* p);
    /// Calculates the resulting photon energy after scattering with given scattering angle
    double gamma_energy(double inipe, double theta);
    /// Decides which process (Compton, Rayleigh, Photoeffect) is performed next
    unsigned int decideProcess(const double& egamma); //0=compton,1=photoeffekt,2=rayleigh

    const double m_e;     ///< electron mass
    const double alpha;   ///< fine structure constant - not needed!
    TFile* probFile;      ///< input file with relative cross sections
    TF1* tf1_pdf;         ///< ROOT function for the differential klein-nishina cross section
    TGraph* ComptonProb;  ///< ROOT TGraph containing the relative Compton cross section
    TGraph* PhotoEffProb; ///< ROOT TGraph containing the relative photo effect cross section
    TGraph* RaylScatProb; ///< ROOT TGraph containing the relative Rayleigh scattering cross section

  public:
    /// Constructor - opens input ROOT file with relative cross sections and loads the respective TGraph objects 
    photonSim();
    /// Destructor
    ~photonSim();

    /// The differential Klein-Nishina x-section
    double kleinnishina(double inipe, double theta);

    /// simulate one scattering process - Compton or photo effect, depending on the energy
    void simulatePhoton(double& egamma, double& eelectron);
    /// simulate one Compton scattering process
    void simulateCompton(double& egamma, double& eelectron);
    /// simulate one photoelectric absorbtion (photo effect)
    void simulatePhotoEff(double& egamma, double& eelectron);

};
